// source: moderation.proto
/**
 * @fileoverview
 * @enhanceable
 * @suppress {missingRequire} reports error on implicit type usages.
 * @suppress {messageConventions} JS Compiler reports an error if a variable or
 *     field starts with 'MSG_' and isn't a translatable message.
 * @public
 */
// GENERATED CODE -- DO NOT EDIT!
/* eslint-disable */
// @ts-nocheck

var jspb = require('google-protobuf');
var goog = jspb;
var global =
    (typeof globalThis !== 'undefined' && globalThis) ||
    (typeof window !== 'undefined' && window) ||
    (typeof global !== 'undefined' && global) ||
    (typeof self !== 'undefined' && self) ||
    (function () { return this; }).call(null) ||
    Function('return this')();

var google_protobuf_timestamp_pb = require('google-protobuf/google/protobuf/timestamp_pb.js');
goog.object.extend(proto, google_protobuf_timestamp_pb);
var admin_pb = require('./admin_pb.js');
goog.object.extend(proto, admin_pb);
var annotations_pb = require('./annotations_pb.js');
goog.object.extend(proto, annotations_pb);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationLogReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationLogRes', null, global);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationQueueReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationQueueRes', null, global);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationStateReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.GetModerationStateRes', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ListModerationStatesReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ListModerationStatesRes', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerateContentReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerateContentRes', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationAction', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationLogEntryInfo', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationObjectType', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationQueueItemInfo', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationStateInfo', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationTrigger', null, global);
goog.exportSymbol('proto.org.couchers.moderation.ModerationVisibility', null, global);
goog.exportSymbol('proto.org.couchers.moderation.SetUserContentVisibilityReq', null, global);
goog.exportSymbol('proto.org.couchers.moderation.SetUserContentVisibilityRes', null, global);
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ModerationStateInfo = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ModerationStateInfo, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ModerationStateInfo.displayName = 'proto.org.couchers.moderation.ModerationStateInfo';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ModerationQueueItemInfo = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ModerationQueueItemInfo, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ModerationQueueItemInfo.displayName = 'proto.org.couchers.moderation.ModerationQueueItemInfo';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ModerationLogEntryInfo = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ModerationLogEntryInfo, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ModerationLogEntryInfo.displayName = 'proto.org.couchers.moderation.ModerationLogEntryInfo';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationQueueReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.moderation.GetModerationQueueReq.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationQueueReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationQueueReq.displayName = 'proto.org.couchers.moderation.GetModerationQueueReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationQueueRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.moderation.GetModerationQueueRes.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationQueueRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationQueueRes.displayName = 'proto.org.couchers.moderation.GetModerationQueueRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationStateReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationStateReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationStateReq.displayName = 'proto.org.couchers.moderation.GetModerationStateReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationStateRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationStateRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationStateRes.displayName = 'proto.org.couchers.moderation.GetModerationStateRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationLogReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationLogReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationLogReq.displayName = 'proto.org.couchers.moderation.GetModerationLogReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.GetModerationLogRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.moderation.GetModerationLogRes.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.moderation.GetModerationLogRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.GetModerationLogRes.displayName = 'proto.org.couchers.moderation.GetModerationLogRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ModerateContentReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ModerateContentReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ModerateContentReq.displayName = 'proto.org.couchers.moderation.ModerateContentReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ModerateContentRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ModerateContentRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ModerateContentRes.displayName = 'proto.org.couchers.moderation.ModerateContentRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.moderation.SetUserContentVisibilityReq.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.moderation.SetUserContentVisibilityReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.SetUserContentVisibilityReq.displayName = 'proto.org.couchers.moderation.SetUserContentVisibilityReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.SetUserContentVisibilityRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.SetUserContentVisibilityRes.displayName = 'proto.org.couchers.moderation.SetUserContentVisibilityRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ListModerationStatesReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.moderation.ListModerationStatesReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ListModerationStatesReq.displayName = 'proto.org.couchers.moderation.ListModerationStatesReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.moderation.ListModerationStatesRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.moderation.ListModerationStatesRes.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.moderation.ListModerationStatesRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.moderation.ListModerationStatesRes.displayName = 'proto.org.couchers.moderation.ListModerationStatesRes';
}



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ModerationStateInfo.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ModerationStateInfo} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationStateInfo.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationStateId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    objectType: jspb.Message.getFieldWithDefault(msg, 2, 0),
    objectId: jspb.Message.getFieldWithDefault(msg, 3, 0),
    visibility: jspb.Message.getFieldWithDefault(msg, 4, 0),
    created: (f = msg.getCreated()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    updated: (f = msg.getUpdated()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    authorUserId: jspb.Message.getFieldWithDefault(msg, 7, 0),
    content: jspb.Message.getFieldWithDefault(msg, 8, ""),
    author: (f = msg.getAuthor()) && admin_pb.UserDetails.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.ModerationStateInfo.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ModerationStateInfo;
  return proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ModerationStateInfo} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModerationStateId(value);
      break;
    case 2:
      var value = /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (reader.readEnum());
      msg.setObjectType(value);
      break;
    case 3:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setObjectId(value);
      break;
    case 4:
      var value = /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (reader.readEnum());
      msg.setVisibility(value);
      break;
    case 5:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setCreated(value);
      break;
    case 6:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setUpdated(value);
      break;
    case 7:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setAuthorUserId(value);
      break;
    case 8:
      var value = /** @type {string} */ (reader.readString());
      msg.setContent(value);
      break;
    case 9:
      var value = new admin_pb.UserDetails;
      reader.readMessage(value,admin_pb.UserDetails.deserializeBinaryFromReader);
      msg.setAuthor(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ModerationStateInfo} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationStateId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getObjectType();
  if (f !== 0.0) {
    writer.writeEnum(
      2,
      f
    );
  }
  f = message.getObjectId();
  if (f !== 0) {
    writer.writeInt64(
      3,
      f
    );
  }
  f = message.getVisibility();
  if (f !== 0.0) {
    writer.writeEnum(
      4,
      f
    );
  }
  f = message.getCreated();
  if (f != null) {
    writer.writeMessage(
      5,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getUpdated();
  if (f != null) {
    writer.writeMessage(
      6,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getAuthorUserId();
  if (f !== 0) {
    writer.writeInt64(
      7,
      f
    );
  }
  f = message.getContent();
  if (f.length > 0) {
    writer.writeString(
      8,
      f
    );
  }
  f = message.getAuthor();
  if (f != null) {
    writer.writeMessage(
      9,
      f,
      admin_pb.UserDetails.serializeBinaryToWriter
    );
  }
};


/**
 * optional int64 moderation_state_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getModerationStateId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setModerationStateId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional ModerationObjectType object_type = 2;
 * @return {!proto.org.couchers.moderation.ModerationObjectType}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getObjectType = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationObjectType} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setObjectType = function(value) {
  return jspb.Message.setProto3EnumField(this, 2, value);
};


/**
 * optional int64 object_id = 3;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getObjectId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 3, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setObjectId = function(value) {
  return jspb.Message.setProto3IntField(this, 3, value);
};


/**
 * optional ModerationVisibility visibility = 4;
 * @return {!proto.org.couchers.moderation.ModerationVisibility}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getVisibility = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (jspb.Message.getFieldWithDefault(this, 4, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationVisibility} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setVisibility = function(value) {
  return jspb.Message.setProto3EnumField(this, 4, value);
};


/**
 * optional google.protobuf.Timestamp created = 5;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getCreated = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 5));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
*/
proto.org.couchers.moderation.ModerationStateInfo.prototype.setCreated = function(value) {
  return jspb.Message.setWrapperField(this, 5, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.clearCreated = function() {
  return this.setCreated(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.hasCreated = function() {
  return jspb.Message.getField(this, 5) != null;
};


/**
 * optional google.protobuf.Timestamp updated = 6;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getUpdated = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 6));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
*/
proto.org.couchers.moderation.ModerationStateInfo.prototype.setUpdated = function(value) {
  return jspb.Message.setWrapperField(this, 6, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.clearUpdated = function() {
  return this.setUpdated(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.hasUpdated = function() {
  return jspb.Message.getField(this, 6) != null;
};


/**
 * optional int64 author_user_id = 7;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getAuthorUserId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 7, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setAuthorUserId = function(value) {
  return jspb.Message.setProto3IntField(this, 7, value);
};


/**
 * optional string content = 8;
 * @return {string}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getContent = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 8, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.setContent = function(value) {
  return jspb.Message.setProto3StringField(this, 8, value);
};


/**
 * optional org.couchers.admin.UserDetails author = 9;
 * @return {?proto.org.couchers.admin.UserDetails}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.getAuthor = function() {
  return /** @type{?proto.org.couchers.admin.UserDetails} */ (
    jspb.Message.getWrapperField(this, admin_pb.UserDetails, 9));
};


/**
 * @param {?proto.org.couchers.admin.UserDetails|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
*/
proto.org.couchers.moderation.ModerationStateInfo.prototype.setAuthor = function(value) {
  return jspb.Message.setWrapperField(this, 9, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationStateInfo} returns this
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.clearAuthor = function() {
  return this.setAuthor(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationStateInfo.prototype.hasAuthor = function() {
  return jspb.Message.getField(this, 9) != null;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ModerationQueueItemInfo.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ModerationQueueItemInfo} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.toObject = function(includeInstance, msg) {
  var f, obj = {
    queueItemId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    moderationStateId: jspb.Message.getFieldWithDefault(msg, 2, 0),
    timeCreated: (f = msg.getTimeCreated()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    trigger: jspb.Message.getFieldWithDefault(msg, 4, 0),
    reason: jspb.Message.getFieldWithDefault(msg, 5, ""),
    isResolved: jspb.Message.getBooleanFieldWithDefault(msg, 6, false),
    resolvedByLogId: jspb.Message.getFieldWithDefault(msg, 7, 0),
    moderationState: (f = msg.getModerationState()) && proto.org.couchers.moderation.ModerationStateInfo.toObject(includeInstance, f),
    priority: jspb.Message.getFieldWithDefault(msg, 9, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ModerationQueueItemInfo;
  return proto.org.couchers.moderation.ModerationQueueItemInfo.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ModerationQueueItemInfo} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setQueueItemId(value);
      break;
    case 2:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModerationStateId(value);
      break;
    case 3:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setTimeCreated(value);
      break;
    case 4:
      var value = /** @type {!proto.org.couchers.moderation.ModerationTrigger} */ (reader.readEnum());
      msg.setTrigger(value);
      break;
    case 5:
      var value = /** @type {string} */ (reader.readString());
      msg.setReason(value);
      break;
    case 6:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setIsResolved(value);
      break;
    case 7:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setResolvedByLogId(value);
      break;
    case 8:
      var value = new proto.org.couchers.moderation.ModerationStateInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader);
      msg.setModerationState(value);
      break;
    case 9:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setPriority(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ModerationQueueItemInfo.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ModerationQueueItemInfo} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getQueueItemId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getModerationStateId();
  if (f !== 0) {
    writer.writeInt64(
      2,
      f
    );
  }
  f = message.getTimeCreated();
  if (f != null) {
    writer.writeMessage(
      3,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getTrigger();
  if (f !== 0.0) {
    writer.writeEnum(
      4,
      f
    );
  }
  f = message.getReason();
  if (f.length > 0) {
    writer.writeString(
      5,
      f
    );
  }
  f = message.getIsResolved();
  if (f) {
    writer.writeBool(
      6,
      f
    );
  }
  f = message.getResolvedByLogId();
  if (f !== 0) {
    writer.writeInt64(
      7,
      f
    );
  }
  f = message.getModerationState();
  if (f != null) {
    writer.writeMessage(
      8,
      f,
      proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter
    );
  }
  f = message.getPriority();
  if (f !== 0) {
    writer.writeInt32(
      9,
      f
    );
  }
};


/**
 * optional int64 queue_item_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getQueueItemId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setQueueItemId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional int64 moderation_state_id = 2;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getModerationStateId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setModerationStateId = function(value) {
  return jspb.Message.setProto3IntField(this, 2, value);
};


/**
 * optional google.protobuf.Timestamp time_created = 3;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getTimeCreated = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 3));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
*/
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setTimeCreated = function(value) {
  return jspb.Message.setWrapperField(this, 3, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.clearTimeCreated = function() {
  return this.setTimeCreated(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.hasTimeCreated = function() {
  return jspb.Message.getField(this, 3) != null;
};


/**
 * optional ModerationTrigger trigger = 4;
 * @return {!proto.org.couchers.moderation.ModerationTrigger}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getTrigger = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationTrigger} */ (jspb.Message.getFieldWithDefault(this, 4, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationTrigger} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setTrigger = function(value) {
  return jspb.Message.setProto3EnumField(this, 4, value);
};


/**
 * optional string reason = 5;
 * @return {string}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getReason = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 5, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setReason = function(value) {
  return jspb.Message.setProto3StringField(this, 5, value);
};


/**
 * optional bool is_resolved = 6;
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getIsResolved = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 6, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setIsResolved = function(value) {
  return jspb.Message.setProto3BooleanField(this, 6, value);
};


/**
 * optional int64 resolved_by_log_id = 7;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getResolvedByLogId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 7, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setResolvedByLogId = function(value) {
  return jspb.Message.setProto3IntField(this, 7, value);
};


/**
 * optional ModerationStateInfo moderation_state = 8;
 * @return {?proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getModerationState = function() {
  return /** @type{?proto.org.couchers.moderation.ModerationStateInfo} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.moderation.ModerationStateInfo, 8));
};


/**
 * @param {?proto.org.couchers.moderation.ModerationStateInfo|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
*/
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setModerationState = function(value) {
  return jspb.Message.setWrapperField(this, 8, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.clearModerationState = function() {
  return this.setModerationState(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.hasModerationState = function() {
  return jspb.Message.getField(this, 8) != null;
};


/**
 * optional int32 priority = 9;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.getPriority = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 9, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo} returns this
 */
proto.org.couchers.moderation.ModerationQueueItemInfo.prototype.setPriority = function(value) {
  return jspb.Message.setProto3IntField(this, 9, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ModerationLogEntryInfo.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ModerationLogEntryInfo} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.toObject = function(includeInstance, msg) {
  var f, obj = {
    logEntryId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    moderationStateId: jspb.Message.getFieldWithDefault(msg, 2, 0),
    time: (f = msg.getTime()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    action: jspb.Message.getFieldWithDefault(msg, 4, 0),
    moderatorUserId: jspb.Message.getFieldWithDefault(msg, 5, 0),
    newVisibility: jspb.Message.getFieldWithDefault(msg, 6, 0),
    reason: jspb.Message.getFieldWithDefault(msg, 7, ""),
    newPriority: jspb.Message.getFieldWithDefault(msg, 8, 0),
    queueItemId: jspb.Message.getFieldWithDefault(msg, 9, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ModerationLogEntryInfo;
  return proto.org.couchers.moderation.ModerationLogEntryInfo.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ModerationLogEntryInfo} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setLogEntryId(value);
      break;
    case 2:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModerationStateId(value);
      break;
    case 3:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setTime(value);
      break;
    case 4:
      var value = /** @type {!proto.org.couchers.moderation.ModerationAction} */ (reader.readEnum());
      msg.setAction(value);
      break;
    case 5:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModeratorUserId(value);
      break;
    case 6:
      var value = /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (reader.readEnum());
      msg.setNewVisibility(value);
      break;
    case 7:
      var value = /** @type {string} */ (reader.readString());
      msg.setReason(value);
      break;
    case 8:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setNewPriority(value);
      break;
    case 9:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setQueueItemId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ModerationLogEntryInfo.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ModerationLogEntryInfo} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getLogEntryId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getModerationStateId();
  if (f !== 0) {
    writer.writeInt64(
      2,
      f
    );
  }
  f = message.getTime();
  if (f != null) {
    writer.writeMessage(
      3,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getAction();
  if (f !== 0.0) {
    writer.writeEnum(
      4,
      f
    );
  }
  f = message.getModeratorUserId();
  if (f !== 0) {
    writer.writeInt64(
      5,
      f
    );
  }
  f = message.getNewVisibility();
  if (f !== 0.0) {
    writer.writeEnum(
      6,
      f
    );
  }
  f = message.getReason();
  if (f.length > 0) {
    writer.writeString(
      7,
      f
    );
  }
  f = message.getNewPriority();
  if (f !== 0) {
    writer.writeInt32(
      8,
      f
    );
  }
  f = message.getQueueItemId();
  if (f !== 0) {
    writer.writeInt64(
      9,
      f
    );
  }
};


/**
 * optional int64 log_entry_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getLogEntryId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setLogEntryId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional int64 moderation_state_id = 2;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getModerationStateId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setModerationStateId = function(value) {
  return jspb.Message.setProto3IntField(this, 2, value);
};


/**
 * optional google.protobuf.Timestamp time = 3;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getTime = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 3));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
*/
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setTime = function(value) {
  return jspb.Message.setWrapperField(this, 3, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.clearTime = function() {
  return this.setTime(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.hasTime = function() {
  return jspb.Message.getField(this, 3) != null;
};


/**
 * optional ModerationAction action = 4;
 * @return {!proto.org.couchers.moderation.ModerationAction}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getAction = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationAction} */ (jspb.Message.getFieldWithDefault(this, 4, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationAction} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setAction = function(value) {
  return jspb.Message.setProto3EnumField(this, 4, value);
};


/**
 * optional int64 moderator_user_id = 5;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getModeratorUserId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 5, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setModeratorUserId = function(value) {
  return jspb.Message.setProto3IntField(this, 5, value);
};


/**
 * optional ModerationVisibility new_visibility = 6;
 * @return {!proto.org.couchers.moderation.ModerationVisibility}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getNewVisibility = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (jspb.Message.getFieldWithDefault(this, 6, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationVisibility} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setNewVisibility = function(value) {
  return jspb.Message.setProto3EnumField(this, 6, value);
};


/**
 * optional string reason = 7;
 * @return {string}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getReason = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 7, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setReason = function(value) {
  return jspb.Message.setProto3StringField(this, 7, value);
};


/**
 * optional int32 new_priority = 8;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getNewPriority = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 8, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setNewPriority = function(value) {
  return jspb.Message.setProto3IntField(this, 8, value);
};


/**
 * optional int64 queue_item_id = 9;
 * @return {number}
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.getQueueItemId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 9, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo} returns this
 */
proto.org.couchers.moderation.ModerationLogEntryInfo.prototype.setQueueItemId = function(value) {
  return jspb.Message.setProto3IntField(this, 9, value);
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.moderation.GetModerationQueueReq.repeatedFields_ = [4];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationQueueReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationQueueReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationQueueReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    triggersList: (f = jspb.Message.getRepeatedField(msg, 4)) == null ? undefined : f,
    objectType: jspb.Message.getFieldWithDefault(msg, 5, 0),
    unresolvedOnly: jspb.Message.getBooleanFieldWithDefault(msg, 6, false),
    createdBefore: (f = msg.getCreatedBefore()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    createdAfter: (f = msg.getCreatedAfter()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    itemAuthorUserId: jspb.Message.getFieldWithDefault(msg, 9, 0),
    priorityMin: jspb.Message.getFieldWithDefault(msg, 10, 0),
    priorityMax: jspb.Message.getFieldWithDefault(msg, 11, 0),
    pageSize: jspb.Message.getFieldWithDefault(msg, 1, 0),
    pageToken: jspb.Message.getFieldWithDefault(msg, 2, ""),
    newestFirst: jspb.Message.getBooleanFieldWithDefault(msg, 3, false)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq}
 */
proto.org.couchers.moderation.GetModerationQueueReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationQueueReq;
  return proto.org.couchers.moderation.GetModerationQueueReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationQueueReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq}
 */
proto.org.couchers.moderation.GetModerationQueueReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 4:
      var values = /** @type {!Array<!proto.org.couchers.moderation.ModerationTrigger>} */ (reader.isDelimited() ? reader.readPackedEnum() : [reader.readEnum()]);
      for (var i = 0; i < values.length; i++) {
        msg.addTriggers(values[i]);
      }
      break;
    case 5:
      var value = /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (reader.readEnum());
      msg.setObjectType(value);
      break;
    case 6:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setUnresolvedOnly(value);
      break;
    case 7:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setCreatedBefore(value);
      break;
    case 8:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setCreatedAfter(value);
      break;
    case 9:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setItemAuthorUserId(value);
      break;
    case 10:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setPriorityMin(value);
      break;
    case 11:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setPriorityMax(value);
      break;
    case 1:
      var value = /** @type {number} */ (reader.readUint32());
      msg.setPageSize(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setPageToken(value);
      break;
    case 3:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setNewestFirst(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationQueueReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationQueueReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationQueueReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getTriggersList();
  if (f.length > 0) {
    writer.writePackedEnum(
      4,
      f
    );
  }
  f = message.getObjectType();
  if (f !== 0.0) {
    writer.writeEnum(
      5,
      f
    );
  }
  f = message.getUnresolvedOnly();
  if (f) {
    writer.writeBool(
      6,
      f
    );
  }
  f = message.getCreatedBefore();
  if (f != null) {
    writer.writeMessage(
      7,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getCreatedAfter();
  if (f != null) {
    writer.writeMessage(
      8,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getItemAuthorUserId();
  if (f !== 0) {
    writer.writeInt64(
      9,
      f
    );
  }
  f = /** @type {number} */ (jspb.Message.getField(message, 10));
  if (f != null) {
    writer.writeInt32(
      10,
      f
    );
  }
  f = /** @type {number} */ (jspb.Message.getField(message, 11));
  if (f != null) {
    writer.writeInt32(
      11,
      f
    );
  }
  f = message.getPageSize();
  if (f !== 0) {
    writer.writeUint32(
      1,
      f
    );
  }
  f = message.getPageToken();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
  f = message.getNewestFirst();
  if (f) {
    writer.writeBool(
      3,
      f
    );
  }
};


/**
 * repeated ModerationTrigger triggers = 4;
 * @return {!Array<!proto.org.couchers.moderation.ModerationTrigger>}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getTriggersList = function() {
  return /** @type {!Array<!proto.org.couchers.moderation.ModerationTrigger>} */ (jspb.Message.getRepeatedField(this, 4));
};


/**
 * @param {!Array<!proto.org.couchers.moderation.ModerationTrigger>} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setTriggersList = function(value) {
  return jspb.Message.setField(this, 4, value || []);
};


/**
 * @param {!proto.org.couchers.moderation.ModerationTrigger} value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.addTriggers = function(value, opt_index) {
  return jspb.Message.addToRepeatedField(this, 4, value, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.clearTriggersList = function() {
  return this.setTriggersList([]);
};


/**
 * optional ModerationObjectType object_type = 5;
 * @return {!proto.org.couchers.moderation.ModerationObjectType}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getObjectType = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (jspb.Message.getFieldWithDefault(this, 5, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationObjectType} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setObjectType = function(value) {
  return jspb.Message.setProto3EnumField(this, 5, value);
};


/**
 * optional bool unresolved_only = 6;
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getUnresolvedOnly = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 6, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setUnresolvedOnly = function(value) {
  return jspb.Message.setProto3BooleanField(this, 6, value);
};


/**
 * optional google.protobuf.Timestamp created_before = 7;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getCreatedBefore = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 7));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
*/
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setCreatedBefore = function(value) {
  return jspb.Message.setWrapperField(this, 7, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.clearCreatedBefore = function() {
  return this.setCreatedBefore(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.hasCreatedBefore = function() {
  return jspb.Message.getField(this, 7) != null;
};


/**
 * optional google.protobuf.Timestamp created_after = 8;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getCreatedAfter = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 8));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
*/
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setCreatedAfter = function(value) {
  return jspb.Message.setWrapperField(this, 8, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.clearCreatedAfter = function() {
  return this.setCreatedAfter(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.hasCreatedAfter = function() {
  return jspb.Message.getField(this, 8) != null;
};


/**
 * optional int64 item_author_user_id = 9;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getItemAuthorUserId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 9, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setItemAuthorUserId = function(value) {
  return jspb.Message.setProto3IntField(this, 9, value);
};


/**
 * optional int32 priority_min = 10;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getPriorityMin = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 10, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setPriorityMin = function(value) {
  return jspb.Message.setField(this, 10, value);
};


/**
 * Clears the field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.clearPriorityMin = function() {
  return jspb.Message.setField(this, 10, undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.hasPriorityMin = function() {
  return jspb.Message.getField(this, 10) != null;
};


/**
 * optional int32 priority_max = 11;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getPriorityMax = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 11, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setPriorityMax = function(value) {
  return jspb.Message.setField(this, 11, value);
};


/**
 * Clears the field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.clearPriorityMax = function() {
  return jspb.Message.setField(this, 11, undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.hasPriorityMax = function() {
  return jspb.Message.getField(this, 11) != null;
};


/**
 * optional uint32 page_size = 1;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getPageSize = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setPageSize = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional string page_token = 2;
 * @return {string}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getPageToken = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setPageToken = function(value) {
  return jspb.Message.setProto3StringField(this, 2, value);
};


/**
 * optional bool newest_first = 3;
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.getNewestFirst = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 3, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueReq} returns this
 */
proto.org.couchers.moderation.GetModerationQueueReq.prototype.setNewestFirst = function(value) {
  return jspb.Message.setProto3BooleanField(this, 3, value);
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.moderation.GetModerationQueueRes.repeatedFields_ = [1];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationQueueRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationQueueRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationQueueRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    queueItemsList: jspb.Message.toObjectList(msg.getQueueItemsList(),
    proto.org.couchers.moderation.ModerationQueueItemInfo.toObject, includeInstance),
    nextPageToken: jspb.Message.getFieldWithDefault(msg, 2, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationQueueRes}
 */
proto.org.couchers.moderation.GetModerationQueueRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationQueueRes;
  return proto.org.couchers.moderation.GetModerationQueueRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationQueueRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationQueueRes}
 */
proto.org.couchers.moderation.GetModerationQueueRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.moderation.ModerationQueueItemInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationQueueItemInfo.deserializeBinaryFromReader);
      msg.addQueueItems(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setNextPageToken(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationQueueRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationQueueRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationQueueRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getQueueItemsList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      1,
      f,
      proto.org.couchers.moderation.ModerationQueueItemInfo.serializeBinaryToWriter
    );
  }
  f = message.getNextPageToken();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
};


/**
 * repeated ModerationQueueItemInfo queue_items = 1;
 * @return {!Array<!proto.org.couchers.moderation.ModerationQueueItemInfo>}
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.getQueueItemsList = function() {
  return /** @type{!Array<!proto.org.couchers.moderation.ModerationQueueItemInfo>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.org.couchers.moderation.ModerationQueueItemInfo, 1));
};


/**
 * @param {!Array<!proto.org.couchers.moderation.ModerationQueueItemInfo>} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueRes} returns this
*/
proto.org.couchers.moderation.GetModerationQueueRes.prototype.setQueueItemsList = function(value) {
  return jspb.Message.setRepeatedWrapperField(this, 1, value);
};


/**
 * @param {!proto.org.couchers.moderation.ModerationQueueItemInfo=} opt_value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.moderation.ModerationQueueItemInfo}
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.addQueueItems = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 1, opt_value, proto.org.couchers.moderation.ModerationQueueItemInfo, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.moderation.GetModerationQueueRes} returns this
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.clearQueueItemsList = function() {
  return this.setQueueItemsList([]);
};


/**
 * optional string next_page_token = 2;
 * @return {string}
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.getNextPageToken = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.GetModerationQueueRes} returns this
 */
proto.org.couchers.moderation.GetModerationQueueRes.prototype.setNextPageToken = function(value) {
  return jspb.Message.setProto3StringField(this, 2, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationStateReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationStateReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationStateReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    objectType: jspb.Message.getFieldWithDefault(msg, 1, 0),
    objectId: jspb.Message.getFieldWithDefault(msg, 2, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationStateReq}
 */
proto.org.couchers.moderation.GetModerationStateReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationStateReq;
  return proto.org.couchers.moderation.GetModerationStateReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationStateReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationStateReq}
 */
proto.org.couchers.moderation.GetModerationStateReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (reader.readEnum());
      msg.setObjectType(value);
      break;
    case 2:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setObjectId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationStateReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationStateReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationStateReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getObjectType();
  if (f !== 0.0) {
    writer.writeEnum(
      1,
      f
    );
  }
  f = message.getObjectId();
  if (f !== 0) {
    writer.writeInt64(
      2,
      f
    );
  }
};


/**
 * optional ModerationObjectType object_type = 1;
 * @return {!proto.org.couchers.moderation.ModerationObjectType}
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.getObjectType = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationObjectType} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationObjectType} value
 * @return {!proto.org.couchers.moderation.GetModerationStateReq} returns this
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.setObjectType = function(value) {
  return jspb.Message.setProto3EnumField(this, 1, value);
};


/**
 * optional int64 object_id = 2;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.getObjectId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationStateReq} returns this
 */
proto.org.couchers.moderation.GetModerationStateReq.prototype.setObjectId = function(value) {
  return jspb.Message.setProto3IntField(this, 2, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationStateRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationStateRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationStateRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationStateRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationState: (f = msg.getModerationState()) && proto.org.couchers.moderation.ModerationStateInfo.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationStateRes}
 */
proto.org.couchers.moderation.GetModerationStateRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationStateRes;
  return proto.org.couchers.moderation.GetModerationStateRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationStateRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationStateRes}
 */
proto.org.couchers.moderation.GetModerationStateRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.moderation.ModerationStateInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader);
      msg.setModerationState(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationStateRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationStateRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationStateRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationStateRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationState();
  if (f != null) {
    writer.writeMessage(
      1,
      f,
      proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter
    );
  }
};


/**
 * optional ModerationStateInfo moderation_state = 1;
 * @return {?proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.GetModerationStateRes.prototype.getModerationState = function() {
  return /** @type{?proto.org.couchers.moderation.ModerationStateInfo} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.moderation.ModerationStateInfo, 1));
};


/**
 * @param {?proto.org.couchers.moderation.ModerationStateInfo|undefined} value
 * @return {!proto.org.couchers.moderation.GetModerationStateRes} returns this
*/
proto.org.couchers.moderation.GetModerationStateRes.prototype.setModerationState = function(value) {
  return jspb.Message.setWrapperField(this, 1, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationStateRes} returns this
 */
proto.org.couchers.moderation.GetModerationStateRes.prototype.clearModerationState = function() {
  return this.setModerationState(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationStateRes.prototype.hasModerationState = function() {
  return jspb.Message.getField(this, 1) != null;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationLogReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationLogReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationLogReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationLogReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationStateId: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationLogReq}
 */
proto.org.couchers.moderation.GetModerationLogReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationLogReq;
  return proto.org.couchers.moderation.GetModerationLogReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationLogReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationLogReq}
 */
proto.org.couchers.moderation.GetModerationLogReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModerationStateId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationLogReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationLogReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationLogReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationLogReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationStateId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
};


/**
 * optional int64 moderation_state_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.GetModerationLogReq.prototype.getModerationStateId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.GetModerationLogReq} returns this
 */
proto.org.couchers.moderation.GetModerationLogReq.prototype.setModerationStateId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.moderation.GetModerationLogRes.repeatedFields_ = [1];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.GetModerationLogRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.GetModerationLogRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationLogRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    logEntriesList: jspb.Message.toObjectList(msg.getLogEntriesList(),
    proto.org.couchers.moderation.ModerationLogEntryInfo.toObject, includeInstance),
    moderationState: (f = msg.getModerationState()) && proto.org.couchers.moderation.ModerationStateInfo.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.GetModerationLogRes}
 */
proto.org.couchers.moderation.GetModerationLogRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.GetModerationLogRes;
  return proto.org.couchers.moderation.GetModerationLogRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.GetModerationLogRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.GetModerationLogRes}
 */
proto.org.couchers.moderation.GetModerationLogRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.moderation.ModerationLogEntryInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationLogEntryInfo.deserializeBinaryFromReader);
      msg.addLogEntries(value);
      break;
    case 2:
      var value = new proto.org.couchers.moderation.ModerationStateInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader);
      msg.setModerationState(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.GetModerationLogRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.GetModerationLogRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.GetModerationLogRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getLogEntriesList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      1,
      f,
      proto.org.couchers.moderation.ModerationLogEntryInfo.serializeBinaryToWriter
    );
  }
  f = message.getModerationState();
  if (f != null) {
    writer.writeMessage(
      2,
      f,
      proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter
    );
  }
};


/**
 * repeated ModerationLogEntryInfo log_entries = 1;
 * @return {!Array<!proto.org.couchers.moderation.ModerationLogEntryInfo>}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.getLogEntriesList = function() {
  return /** @type{!Array<!proto.org.couchers.moderation.ModerationLogEntryInfo>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.org.couchers.moderation.ModerationLogEntryInfo, 1));
};


/**
 * @param {!Array<!proto.org.couchers.moderation.ModerationLogEntryInfo>} value
 * @return {!proto.org.couchers.moderation.GetModerationLogRes} returns this
*/
proto.org.couchers.moderation.GetModerationLogRes.prototype.setLogEntriesList = function(value) {
  return jspb.Message.setRepeatedWrapperField(this, 1, value);
};


/**
 * @param {!proto.org.couchers.moderation.ModerationLogEntryInfo=} opt_value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.moderation.ModerationLogEntryInfo}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.addLogEntries = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 1, opt_value, proto.org.couchers.moderation.ModerationLogEntryInfo, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.moderation.GetModerationLogRes} returns this
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.clearLogEntriesList = function() {
  return this.setLogEntriesList([]);
};


/**
 * optional ModerationStateInfo moderation_state = 2;
 * @return {?proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.getModerationState = function() {
  return /** @type{?proto.org.couchers.moderation.ModerationStateInfo} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.moderation.ModerationStateInfo, 2));
};


/**
 * @param {?proto.org.couchers.moderation.ModerationStateInfo|undefined} value
 * @return {!proto.org.couchers.moderation.GetModerationLogRes} returns this
*/
proto.org.couchers.moderation.GetModerationLogRes.prototype.setModerationState = function(value) {
  return jspb.Message.setWrapperField(this, 2, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.GetModerationLogRes} returns this
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.clearModerationState = function() {
  return this.setModerationState(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.GetModerationLogRes.prototype.hasModerationState = function() {
  return jspb.Message.getField(this, 2) != null;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ModerateContentReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ModerateContentReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerateContentReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationStateId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    action: jspb.Message.getFieldWithDefault(msg, 2, 0),
    visibility: jspb.Message.getFieldWithDefault(msg, 3, 0),
    reason: jspb.Message.getFieldWithDefault(msg, 4, ""),
    priority: jspb.Message.getFieldWithDefault(msg, 5, 0),
    queueItemId: jspb.Message.getFieldWithDefault(msg, 6, 0),
    trigger: jspb.Message.getFieldWithDefault(msg, 7, 0),
    supersedeQueueItemId: jspb.Message.getFieldWithDefault(msg, 8, 0),
    clearFlags: jspb.Message.getBooleanFieldWithDefault(msg, 9, false)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ModerateContentReq}
 */
proto.org.couchers.moderation.ModerateContentReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ModerateContentReq;
  return proto.org.couchers.moderation.ModerateContentReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ModerateContentReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ModerateContentReq}
 */
proto.org.couchers.moderation.ModerateContentReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setModerationStateId(value);
      break;
    case 2:
      var value = /** @type {!proto.org.couchers.moderation.ModerationAction} */ (reader.readEnum());
      msg.setAction(value);
      break;
    case 3:
      var value = /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (reader.readEnum());
      msg.setVisibility(value);
      break;
    case 4:
      var value = /** @type {string} */ (reader.readString());
      msg.setReason(value);
      break;
    case 5:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setPriority(value);
      break;
    case 6:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setQueueItemId(value);
      break;
    case 7:
      var value = /** @type {!proto.org.couchers.moderation.ModerationTrigger} */ (reader.readEnum());
      msg.setTrigger(value);
      break;
    case 8:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setSupersedeQueueItemId(value);
      break;
    case 9:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setClearFlags(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ModerateContentReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ModerateContentReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerateContentReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationStateId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getAction();
  if (f !== 0.0) {
    writer.writeEnum(
      2,
      f
    );
  }
  f = message.getVisibility();
  if (f !== 0.0) {
    writer.writeEnum(
      3,
      f
    );
  }
  f = message.getReason();
  if (f.length > 0) {
    writer.writeString(
      4,
      f
    );
  }
  f = message.getPriority();
  if (f !== 0) {
    writer.writeInt32(
      5,
      f
    );
  }
  f = message.getQueueItemId();
  if (f !== 0) {
    writer.writeInt64(
      6,
      f
    );
  }
  f = message.getTrigger();
  if (f !== 0.0) {
    writer.writeEnum(
      7,
      f
    );
  }
  f = message.getSupersedeQueueItemId();
  if (f !== 0) {
    writer.writeInt64(
      8,
      f
    );
  }
  f = message.getClearFlags();
  if (f) {
    writer.writeBool(
      9,
      f
    );
  }
};


/**
 * optional int64 moderation_state_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getModerationStateId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setModerationStateId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional ModerationAction action = 2;
 * @return {!proto.org.couchers.moderation.ModerationAction}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getAction = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationAction} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationAction} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setAction = function(value) {
  return jspb.Message.setProto3EnumField(this, 2, value);
};


/**
 * optional ModerationVisibility visibility = 3;
 * @return {!proto.org.couchers.moderation.ModerationVisibility}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getVisibility = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (jspb.Message.getFieldWithDefault(this, 3, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationVisibility} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setVisibility = function(value) {
  return jspb.Message.setProto3EnumField(this, 3, value);
};


/**
 * optional string reason = 4;
 * @return {string}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getReason = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 4, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setReason = function(value) {
  return jspb.Message.setProto3StringField(this, 4, value);
};


/**
 * optional int32 priority = 5;
 * @return {number}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getPriority = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 5, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setPriority = function(value) {
  return jspb.Message.setProto3IntField(this, 5, value);
};


/**
 * optional int64 queue_item_id = 6;
 * @return {number}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getQueueItemId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 6, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setQueueItemId = function(value) {
  return jspb.Message.setProto3IntField(this, 6, value);
};


/**
 * optional ModerationTrigger trigger = 7;
 * @return {!proto.org.couchers.moderation.ModerationTrigger}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getTrigger = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationTrigger} */ (jspb.Message.getFieldWithDefault(this, 7, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationTrigger} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setTrigger = function(value) {
  return jspb.Message.setProto3EnumField(this, 7, value);
};


/**
 * optional int64 supersede_queue_item_id = 8;
 * @return {number}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getSupersedeQueueItemId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 8, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setSupersedeQueueItemId = function(value) {
  return jspb.Message.setProto3IntField(this, 8, value);
};


/**
 * optional bool clear_flags = 9;
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.getClearFlags = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 9, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.moderation.ModerateContentReq} returns this
 */
proto.org.couchers.moderation.ModerateContentReq.prototype.setClearFlags = function(value) {
  return jspb.Message.setProto3BooleanField(this, 9, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ModerateContentRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ModerateContentRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ModerateContentRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerateContentRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationState: (f = msg.getModerationState()) && proto.org.couchers.moderation.ModerationStateInfo.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ModerateContentRes}
 */
proto.org.couchers.moderation.ModerateContentRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ModerateContentRes;
  return proto.org.couchers.moderation.ModerateContentRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ModerateContentRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ModerateContentRes}
 */
proto.org.couchers.moderation.ModerateContentRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.moderation.ModerationStateInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader);
      msg.setModerationState(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ModerateContentRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ModerateContentRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ModerateContentRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ModerateContentRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationState();
  if (f != null) {
    writer.writeMessage(
      1,
      f,
      proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter
    );
  }
};


/**
 * optional ModerationStateInfo moderation_state = 1;
 * @return {?proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.ModerateContentRes.prototype.getModerationState = function() {
  return /** @type{?proto.org.couchers.moderation.ModerationStateInfo} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.moderation.ModerationStateInfo, 1));
};


/**
 * @param {?proto.org.couchers.moderation.ModerationStateInfo|undefined} value
 * @return {!proto.org.couchers.moderation.ModerateContentRes} returns this
*/
proto.org.couchers.moderation.ModerateContentRes.prototype.setModerationState = function(value) {
  return jspb.Message.setWrapperField(this, 1, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.moderation.ModerateContentRes} returns this
 */
proto.org.couchers.moderation.ModerateContentRes.prototype.clearModerationState = function() {
  return this.setModerationState(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.moderation.ModerateContentRes.prototype.hasModerationState = function() {
  return jspb.Message.getField(this, 1) != null;
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.repeatedFields_ = [4];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.SetUserContentVisibilityReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    userId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    visibility: jspb.Message.getFieldWithDefault(msg, 2, 0),
    reason: jspb.Message.getFieldWithDefault(msg, 3, ""),
    fromVisibilityList: (f = jspb.Message.getRepeatedField(msg, 4)) == null ? undefined : f
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.SetUserContentVisibilityReq;
  return proto.org.couchers.moderation.SetUserContentVisibilityReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setUserId(value);
      break;
    case 2:
      var value = /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (reader.readEnum());
      msg.setVisibility(value);
      break;
    case 3:
      var value = /** @type {string} */ (reader.readString());
      msg.setReason(value);
      break;
    case 4:
      var values = /** @type {!Array<!proto.org.couchers.moderation.ModerationVisibility>} */ (reader.isDelimited() ? reader.readPackedEnum() : [reader.readEnum()]);
      for (var i = 0; i < values.length; i++) {
        msg.addFromVisibility(values[i]);
      }
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.SetUserContentVisibilityReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getUserId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getVisibility();
  if (f !== 0.0) {
    writer.writeEnum(
      2,
      f
    );
  }
  f = message.getReason();
  if (f.length > 0) {
    writer.writeString(
      3,
      f
    );
  }
  f = message.getFromVisibilityList();
  if (f.length > 0) {
    writer.writePackedEnum(
      4,
      f
    );
  }
};


/**
 * optional int64 user_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.getUserId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.setUserId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional ModerationVisibility visibility = 2;
 * @return {!proto.org.couchers.moderation.ModerationVisibility}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.getVisibility = function() {
  return /** @type {!proto.org.couchers.moderation.ModerationVisibility} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {!proto.org.couchers.moderation.ModerationVisibility} value
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.setVisibility = function(value) {
  return jspb.Message.setProto3EnumField(this, 2, value);
};


/**
 * optional string reason = 3;
 * @return {string}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.getReason = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 3, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.setReason = function(value) {
  return jspb.Message.setProto3StringField(this, 3, value);
};


/**
 * repeated ModerationVisibility from_visibility = 4;
 * @return {!Array<!proto.org.couchers.moderation.ModerationVisibility>}
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.getFromVisibilityList = function() {
  return /** @type {!Array<!proto.org.couchers.moderation.ModerationVisibility>} */ (jspb.Message.getRepeatedField(this, 4));
};


/**
 * @param {!Array<!proto.org.couchers.moderation.ModerationVisibility>} value
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.setFromVisibilityList = function(value) {
  return jspb.Message.setField(this, 4, value || []);
};


/**
 * @param {!proto.org.couchers.moderation.ModerationVisibility} value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.addFromVisibility = function(value, opt_index) {
  return jspb.Message.addToRepeatedField(this, 4, value, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityReq} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityReq.prototype.clearFromVisibilityList = function() {
  return this.setFromVisibilityList([]);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.SetUserContentVisibilityRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    updatedCount: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityRes}
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.SetUserContentVisibilityRes;
  return proto.org.couchers.moderation.SetUserContentVisibilityRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityRes}
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setUpdatedCount(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.SetUserContentVisibilityRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.SetUserContentVisibilityRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getUpdatedCount();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
};


/**
 * optional int64 updated_count = 1;
 * @return {number}
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.prototype.getUpdatedCount = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.SetUserContentVisibilityRes} returns this
 */
proto.org.couchers.moderation.SetUserContentVisibilityRes.prototype.setUpdatedCount = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ListModerationStatesReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ListModerationStatesReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ListModerationStatesReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    authorUserId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    pageSize: jspb.Message.getFieldWithDefault(msg, 2, 0),
    pageToken: jspb.Message.getFieldWithDefault(msg, 3, ""),
    newestFirst: jspb.Message.getBooleanFieldWithDefault(msg, 4, false)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq}
 */
proto.org.couchers.moderation.ListModerationStatesReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ListModerationStatesReq;
  return proto.org.couchers.moderation.ListModerationStatesReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ListModerationStatesReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq}
 */
proto.org.couchers.moderation.ListModerationStatesReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setAuthorUserId(value);
      break;
    case 2:
      var value = /** @type {number} */ (reader.readUint32());
      msg.setPageSize(value);
      break;
    case 3:
      var value = /** @type {string} */ (reader.readString());
      msg.setPageToken(value);
      break;
    case 4:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setNewestFirst(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ListModerationStatesReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ListModerationStatesReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ListModerationStatesReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getAuthorUserId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getPageSize();
  if (f !== 0) {
    writer.writeUint32(
      2,
      f
    );
  }
  f = message.getPageToken();
  if (f.length > 0) {
    writer.writeString(
      3,
      f
    );
  }
  f = message.getNewestFirst();
  if (f) {
    writer.writeBool(
      4,
      f
    );
  }
};


/**
 * optional int64 author_user_id = 1;
 * @return {number}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.getAuthorUserId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq} returns this
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.setAuthorUserId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional uint32 page_size = 2;
 * @return {number}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.getPageSize = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq} returns this
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.setPageSize = function(value) {
  return jspb.Message.setProto3IntField(this, 2, value);
};


/**
 * optional string page_token = 3;
 * @return {string}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.getPageToken = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 3, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq} returns this
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.setPageToken = function(value) {
  return jspb.Message.setProto3StringField(this, 3, value);
};


/**
 * optional bool newest_first = 4;
 * @return {boolean}
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.getNewestFirst = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 4, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesReq} returns this
 */
proto.org.couchers.moderation.ListModerationStatesReq.prototype.setNewestFirst = function(value) {
  return jspb.Message.setProto3BooleanField(this, 4, value);
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.moderation.ListModerationStatesRes.repeatedFields_ = [1];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.moderation.ListModerationStatesRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.moderation.ListModerationStatesRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ListModerationStatesRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    moderationStatesList: jspb.Message.toObjectList(msg.getModerationStatesList(),
    proto.org.couchers.moderation.ModerationStateInfo.toObject, includeInstance),
    nextPageToken: jspb.Message.getFieldWithDefault(msg, 2, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.moderation.ListModerationStatesRes}
 */
proto.org.couchers.moderation.ListModerationStatesRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.moderation.ListModerationStatesRes;
  return proto.org.couchers.moderation.ListModerationStatesRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.moderation.ListModerationStatesRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.moderation.ListModerationStatesRes}
 */
proto.org.couchers.moderation.ListModerationStatesRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.moderation.ModerationStateInfo;
      reader.readMessage(value,proto.org.couchers.moderation.ModerationStateInfo.deserializeBinaryFromReader);
      msg.addModerationStates(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setNextPageToken(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.moderation.ListModerationStatesRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.moderation.ListModerationStatesRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.moderation.ListModerationStatesRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getModerationStatesList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      1,
      f,
      proto.org.couchers.moderation.ModerationStateInfo.serializeBinaryToWriter
    );
  }
  f = message.getNextPageToken();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
};


/**
 * repeated ModerationStateInfo moderation_states = 1;
 * @return {!Array<!proto.org.couchers.moderation.ModerationStateInfo>}
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.getModerationStatesList = function() {
  return /** @type{!Array<!proto.org.couchers.moderation.ModerationStateInfo>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.org.couchers.moderation.ModerationStateInfo, 1));
};


/**
 * @param {!Array<!proto.org.couchers.moderation.ModerationStateInfo>} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesRes} returns this
*/
proto.org.couchers.moderation.ListModerationStatesRes.prototype.setModerationStatesList = function(value) {
  return jspb.Message.setRepeatedWrapperField(this, 1, value);
};


/**
 * @param {!proto.org.couchers.moderation.ModerationStateInfo=} opt_value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.moderation.ModerationStateInfo}
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.addModerationStates = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 1, opt_value, proto.org.couchers.moderation.ModerationStateInfo, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.moderation.ListModerationStatesRes} returns this
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.clearModerationStatesList = function() {
  return this.setModerationStatesList([]);
};


/**
 * optional string next_page_token = 2;
 * @return {string}
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.getNextPageToken = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.moderation.ListModerationStatesRes} returns this
 */
proto.org.couchers.moderation.ListModerationStatesRes.prototype.setNextPageToken = function(value) {
  return jspb.Message.setProto3StringField(this, 2, value);
};


/**
 * @enum {number}
 */
proto.org.couchers.moderation.ModerationVisibility = {
  MODERATION_VISIBILITY_UNSPECIFIED: 0,
  MODERATION_VISIBILITY_HIDDEN: 1,
  MODERATION_VISIBILITY_SHADOWED: 2,
  MODERATION_VISIBILITY_VISIBLE: 3,
  MODERATION_VISIBILITY_UNLISTED: 4
};

/**
 * @enum {number}
 */
proto.org.couchers.moderation.ModerationTrigger = {
  MODERATION_TRIGGER_UNSPECIFIED: 0,
  MODERATION_TRIGGER_INITIAL_REVIEW: 1,
  MODERATION_TRIGGER_USER_FLAG: 2,
  MODERATION_TRIGGER_MACHINE_FLAG: 3,
  MODERATION_TRIGGER_MODERATOR_REVIEW: 4
};

/**
 * @enum {number}
 */
proto.org.couchers.moderation.ModerationAction = {
  MODERATION_ACTION_UNSPECIFIED: 0,
  MODERATION_ACTION_CREATE: 1,
  MODERATION_ACTION_APPROVE: 2,
  MODERATION_ACTION_HIDE: 3,
  MODERATION_ACTION_FLAG: 4,
  MODERATION_ACTION_UNFLAG: 5,
  MODERATION_ACTION_BULK_SET_VISIBILITY: 6,
  MODERATION_ACTION_SET_PRIORITY: 7
};

/**
 * @enum {number}
 */
proto.org.couchers.moderation.ModerationObjectType = {
  MODERATION_OBJECT_TYPE_UNSPECIFIED: 0,
  MODERATION_OBJECT_TYPE_HOST_REQUEST: 1,
  MODERATION_OBJECT_TYPE_GROUP_CHAT: 2,
  MODERATION_OBJECT_TYPE_FRIEND_REQUEST: 3,
  MODERATION_OBJECT_TYPE_EVENT_OCCURRENCE: 4,
  MODERATION_OBJECT_TYPE_COMMENT: 5,
  MODERATION_OBJECT_TYPE_REPLY: 6,
  MODERATION_OBJECT_TYPE_DISCUSSION: 7,
  MODERATION_OBJECT_TYPE_REFERENCE: 8
};

goog.object.extend(exports, proto.org.couchers.moderation);
